@@ -472,7 +472,11 @@ run_source_code <- function(script, run_dir) {
   if (file.exists(source_tarball)) {
     source_tmp_dir <- tempfile()
     on.exit(unlink(source_tmp_dir, recursive = TRUE))
-    utils::untar(source_tarball, exdir = source_tmp_dir, compressed = TRUE)
+    if (is_windows())
+      tar <- "internal"
+    else
+      tar = Sys.getenv("tar")
+    utils::untar(source_tarball, exdir = source_tmp_dir, compressed = TRUE, tar = tar)
     source_dir <- file.path(source_tmp_dir, "source")
     source_files <- list.files(source_dir, recursive = TRUE)
     source_files <- c(script, source_files[!grepl(paste0("^", script, "$"), source_files)])
